@@ -1,5 +1,4 @@
 import logging
-import warnings
 
 from paste.deploy.converters import asbool, aslist
 
@@ -11,14 +10,13 @@ from pylons.decorators import jsonify
 from pylons.templating import render_mako as render
 
 from sqlalchemy.orm import class_mapper
-from sqlalchemy.orm.exc import NoResultFound
 
 import mako
 
-import simplejson as json
-
-from restler.decorators import privileged
-"""Set `privileged` BEFORE importing this module, if needed."""
+try:
+    import json
+except ImportError:
+    import simplejson as json
 
 
 log = logging.getLogger(__name__)
@@ -99,6 +97,20 @@ class Controller(WSGIController):
     def get_db_session(self):
         raise NotImplementedError
 
+    @property
+    def collection_path(self):
+        try:
+            self._collection_path
+        except AttributeError:
+            self._collection_path = '/'.join((
+                request.path.rsplit(self.collection_name, 1)[0].rstrip('/'),
+                self.collection_name))
+        return self._collection_path
+
+    def get_member_path(self, member):
+        id = getattr(member, 'id_str', None)
+        return '{0}/{1}'.format(self.collection_path, id)
+
     def index(self):
         self.set_collection()
         return self._render()
@@ -115,7 +127,6 @@ class Controller(WSGIController):
         self.set_member(id)
         return self._render()
 
-    @privileged
     def create(self):
         self.set_member()
         self._update_member_with_params()
@@ -124,7 +135,6 @@ class Controller(WSGIController):
         self.db_session.commit()
         self._redirect_to_member()
 
-    @privileged
     def update(self, id):
         self.set_member(id)
         self._update_member_with_params()
@@ -132,7 +142,6 @@ class Controller(WSGIController):
         self.db_session.commit()
         self._redirect_to_member()
 
-    @privileged
     def delete(self, id):
         self.set_member(id)
         self.db_session.delete(self.member)
@@ -213,11 +222,7 @@ class Controller(WSGIController):
 
     def convert_param(self, name, val):
         """Convert param value (string) to Python value."""
-        return val
-
-    def _convert_param_for_update(self, name, val):
-        warnings.warn(DeprecationWarning('Use `convert_param` method instead.'))
-        return self.convert_param(name, val)
+        return self.entity.convert_param(name, val)
 
     def _redirect_to_member(self, member=None, relay_params=None, params=None):
         """Redirect to a specific ``member``, defaulting to `self.member`.
@@ -314,10 +319,14 @@ class Controller(WSGIController):
         if self.collection is not None:
             log.debug('Rendering collection')
             obj = self.entity.to_simple_collection(self.collection, self.fields)
+            for member, simple_member in zip(self.collection, obj):
+                simple_member['__path__'] = self.get_member_path(member)
             result_count = len(obj)
         elif self.member is not None:
             log.debug('Rendering member')
-            obj = [self.member.to_simple_object(self.fields)]
+            obj = self.member.to_simple_object(self.fields)
+            obj['__path__'] = self.get_member_path(self.member)
+            obj = [obj]
             result_count = 1
         else:
             log.debug('Neither collection nor member was set.')
@@ -329,6 +338,14 @@ class Controller(WSGIController):
                 response=dict(
                     results=obj,
                     result_count=result_count,
+                    request=dict(
+                        method=request.method,
+                        app_url=request.application_url,
+                        path=request.path,
+                        collection_path=self.collection_path,
+                        params=(request.params.items() or None),
+                        query_string=(request.query_string or None),
+                    ),
                 )
             )
         # Further modify ``obj`` if ``block`` given
